#!/bin/bash
#MOD_REQ#

# CONSTANTES
# Número de reglas que generan reporte
export NUM_REG_REP=3 #MOD_REQ#
export MI_PATH=$(pwd)
# VARIABLES
export LIBRERIA="${MI_PATH}/scripts/lib_TC.sh"
export LOG="log_TC"
# FUNCIONES

######################################################################
#                   Nombre función: check_lib                        #
#    Descripción: comprueba que lib_TC.sh existe y tiene permisos    #
######################################################################
function check_lib()
{
	if [ -d scripts ]
	then
		echo "[INFO] ---- Existe directorio de scripts" >> $LOG
		if [ -f $LIBRERIA ]
		then
			echo "[INFO] ---- lib_TC.sh existe" >> $LOG
			if [ -x $LIBRERIA ]
			then
				echo "[INFO] ---- lib_TC.sh tiene permisos de ejecución" >> $LOG
			else
				chmod +x $LIBRERIA
				echo "[INFO] ---- Permisos otorgados a lib_TC.sh" | tee -a $LOG
			fi
		else
			echo "[ERROR] 002 lib_TC.sh no existe" | tee -a $LOG
			exit 1;
		fi
	else
		echo "[ERROR] 001 Directorio scripts no encontrado" | tee -a $LOG
		exit 1;
	fi
}

# Por si no lo hemos movido anteriormente
[ -f $LOG ] && rm $LOG

######################################################################
#                      Inicio de lanzador_TC.sh                      #
######################################################################

echo "            ################################################################" | tee -a $LOG
echo "            #        Herramienta de transformación de código fuente        #" | tee -a $LOG
echo "            #                                                              #" | tee -a $LOG
echo "            #     Ejemplo de aplicación: código C/C++                      #" | tee -a $LOG
echo "            #                a código C/C++ con un estilo concreto         #" | tee -a $LOG
echo "            #                                                              #" | tee -a $LOG
echo "            #       Trabajo de Fin de Grado de Álvaro Fraile Cáceres       #" | tee -a $LOG
echo "            #             Tutores:                                         #" | tee -a $LOG
echo "            #                 - Podar Cristea, Smaranda                    #" | tee -a $LOG
echo "            #                 - Mazaeda Echevarria, Rogelio                #" | tee -a $LOG
echo "            ################################################################" | tee -a $LOG

######################################################################
#                            Código                                  #
######################################################################

check_lib

# source nos "pasa las variables de hijo a padre"
source $LIBRERIA

# Comprobamos que todos los directorios están creados
check_dir

# Extraemos las variables de configuración
check_conf

# Convertimos los archivos a tratar en formato UNIX
dos2unix -k -q $WORKSHOP

# Comprobamos que los scripts tienen permisos de ejecución
check_perm

# Comprobamos que los parámetros de ejecución son correctos
check_param $1 $#

# Obtenemos las reglas activas
check_reglas

# Creamos el directorio de la secuencia actual
crea_dir_seq

if [[ $1 == "D" ]]
then
	. $DETECTOR
	log "La herramienta finalizó correctamente" "TI"
elif [[ $1 == "DC" ]]
then
	. $DETECTOR
	. $CORRECTOR
	
	log "La herramienta finalizó correctamente" "TI"
	log "Los ficheros modificados se encuentran en ${RUTA_CORREGIDOS}" "TI"
elif [[ $1 == "R" ]]
then
	for (( i=1; i <= (${#regla[*]} - $NUM_REG_REP); i++ ))
	do
		regla[$i]=0
	done
	log "Reglas de corrección desactivadas" "TI"
	. $DETECTOR
	
	log "La herramienta finalizó correctamente" "TI"
fi


exit 0;




